#
# spec file for package pcr-oracle
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# needssslcertforbuild


Name:           pcr-oracle
Version:        0.5.7
Release:        1.1
Summary:        Predict TPM PCR values
License:        GPL-2.0-or-later
Group:          System/Boot
URL:            https://github.com/openSUSE/pcr-oracle
Source:         %{name}-%{version}.tar.xz
BuildRequires:  libelf-devel
BuildRequires:  libfdisk-devel
BuildRequires:  libopenssl-devel >= 3.0.0
BuildRequires:  tpm2-0-tss-devel >= 2.4.0
Requires:       libtss2-tcti-device0
ExclusiveArch:  x86_64 aarch64 ppc64le riscv64

%description
This utility tries to predict the values of the TPM's Platform
Configuration Registers following an update of system components
like shim, grub, etc.

%prep
%autosetup -p1

%build
# beware, this is not autoconf
./configure --prefix /usr
make CCOPT="%optflags"

%install
make install DESTDIR=%{buildroot}
install -d %{buildroot}/%{_bindir}
mv %{buildroot}/bin/pcr-oracle %{buildroot}/%{_bindir}
rmdir %{buildroot}/bin

%files
%defattr(-,root,root)
%doc README.md
%doc test-authorized.sh
%{_bindir}/pcr-oracle
%{_mandir}/man8/pcr-oracle.8*

%changelog
* Thu May 29 2025 Gary Ching-Pang Lin <glin@suse.com>
- Update to 0.5.7
  + Support ppc64 events
  + Fix the string comparison for the alternative event
    (bsc#1241957)
- Add the new BuildRequires: libelf-devel and libfdisk-devel
* Tue May 13 2025 Gary Ching-Pang Lin <glin@suse.com>
- Update to 0.5.6
  + rsa: adopt OpenSSL 3.0 API to generate RSA key
  + Drop the code for openSSL < 3.0.0
  + Look for signing authority in alternative database
  (bsc#1241957)
- Bump the requirement of libopenssl-devel to 3.0.0
* Tue Apr  1 2025 Alberto Planas Dominguez <aplanas@suse.com>
- Update to 0.5.5
  + Merge of pending patches into the project
  + No new feature since last release
- Change source to the openSUSE project
- Remove patches (merged)
  + fix-bsc1230316-make-pcr4-hard-requirement.patch
  + fix-bsc1230316-predict-sbatlevelrt.patch
  + fix-bsc1230316-predict-sbatlevelrt-sb-off.patch
  + fix_efi_measure_and_shim.patch
  + fix-event-reshash-for-cryptouuid.patch
  + fix_grub_bls_cmdline.patch
  + fix_grub_bls_entry.patch
  + fix_loader_conf.patch
  + fix-testcase-empty-efi-variables.patch
  + support-ecc-srk.patch
* Fri Mar  7 2025 Gary Ching-Pang Lin <glin@suse.com>
- Add fix-bsc1230316-predict-sbatlevelrt-sb-off.patch to fix the
  prediction of SbatLevelRT when Secure Boot is disabled
  (bsc#1230316)
- Add fix-bsc1230316-make-pcr4-hard-requirement.patch to make PCR4
  a hard requirement for SbatLevelRT prediction (bsc#1230316)
* Wed Feb 26 2025 Gary Ching-Pang Lin <glin@suse.com>
- Add fix-bsc1230316-predict-sbatlevelrt.patch to predict
  SbatLevelRT for the next boot (bsc#1230316)
* Fri Feb 21 2025 Gary Ching-Pang Lin <glin@suse.com>
- Update the License tag to GPL-2.0-or-later to match the license
  declaration in the source files
* Thu Dec 26 2024 Gary Ching-Pang Lin <glin@suse.com>
- Add fix-event-reshash-for-cryptouuid.patch to detect the crypto
  device with the 'cryptouuid' prefix
* Mon Aug  5 2024 Gary Ching-Pang Lin <glin@suse.com>
- Add support-ecc-srk.patch to support ECC SRK
- Add fix-testcase-empty-efi-variables.patch to fix the testcase
  playback on empty EFI variables
* Mon Mar 25 2024 Alberto Planas Dominguez <aplanas@suse.com>
- Add fix_grub_bls_cmdline.patch to include the measurements of the
  cmdline and the linux and initrd grub commands
* Thu Mar 14 2024 Alberto Planas Dominguez <aplanas@suse.com>
- Add fix_grub_bls_entry.patch to measure boot entries in GRUB BLS
* Mon Feb 26 2024 Alberto Planas Dominguez <aplanas@suse.com>
- Remove fix_efi_measure.patch
- Add fix_efi_measure_and_shim.patch (bsc#1219807)
* Tue Feb 20 2024 Alberto Planas Dominguez <aplanas@suse.com>
- Add fix_loader_conf.patch to measure the systemd-boot loader.conf file
* Fri Jan 12 2024 Alberto Planas Dominguez <aplanas@suse.com>
- Add fix_efi_measure.patch to fix the measurement of EFI binaries
* Fri Dec  8 2023 Gary Ching-Pang Lin <glin@suse.com>
- Update to 0.5.4
  - Improve systemd-boot support
  - Add --boot-entry for systemd-boot
  - Manpage fixes
  - Fix PCR index in JSON file
  - Fix GrubPcrSnapshot parsing
- Drop upstreamed patches: boot_entry.patch and fix_pcr_index.patch
* Wed Nov 29 2023 Alberto Planas Dominguez <aplanas@suse.com>
- Update to 0.5.3
  - Improve documentation
  - Detect key format store via extension
  - Replace --key-format and --policy-format options with a single
  - -target-platform option
  - The json file can contain multiple predictions
- Remove fix_rsa.patch as is already upstream
- Add boot_entry.patch to add new parameter to point to a new systemd
  boot entry
- Add fix_pcr_index.patch to fix the PCR index number in the JSON file
* Mon Nov 20 2023 Alberto Planas Dominguez <aplanas@suse.com>
- Add fix_rsa.patch to support the export in PEM format of the public
  key
* Mon Nov 20 2023 Alberto Planas Dominguez <aplanas@suse.com>
- FAPI is not present until tpm2-tss >= 2.4.0. Express that in the
  BuildRequirement
* Wed Nov 15 2023 Alberto Planas Dominguez <aplanas@suse.com>
- Update to 0.5.2
  - Support EV_EVENT_TAG events from the kernel (PCR9 for the cmdline
    and the kernel)
  - Fix cmdline measurements
- Update to 0.5.1
  - Measure the kernel as an EFI binary (PCR4)
* Mon Nov 13 2023 Alberto Planas Dominguez <aplanas@suse.com>
- Update to 0.5.0
  - Support systemd-cryptenroll JSON files
  - Generate RSA keys in more scenarios
  - Select RSA key size
- Drop systemd-boot.patch (already present in upstream)
* Thu Oct 19 2023 Alberto Planas Dominguez <aplanas@suse.com>
- Add systemd-boot.patch to support systemd-cryptenroll JSON files
* Wed Jul 26 2023 Gary Ching-Pang Lin <glin@suse.com>
- Add libtss2-tcti-device0 as the default TCTI interface to avoid
  the following error:
  Esys_Initialize() Initialize default tcti. ErrorCode (0x000a000a)
* Tue Jul  4 2023 Olaf Kirch <okir@suse.com>
- Added a _service file
- BuildRequire libopenssl-devel rather than openssl
- Updated to version 0.4.6:
  - recognize SOURCE_DATE_EPOCH for reproducible builds
  - Remove authorized policy file from the unseal action
  - Unseal the data without calling __pcr_policy_make()
  - Skip the variable event with 0 length (#26)
  - Add the new parameter: policy-name (#27)
  - Skip the leading operators when matching grub2 commands (#28)
  - microconf change: force rebuilding the sed script
* Mon Jun  5 2023 Gary Ching-Pang Lin <glin@suse.com>
- Update to version 0.4.5
  - update manpage to reflect added support of unseal w/ tpm2.0 key
    format
  - Implement unseal for TPM 2.0 Key File
  - Update manpage to describe the new key-format switch
  - Add TPM 2.0 Key File support to 'seal-secret' and 'sign'
  - Add comment to SRK template regarding NODA flag.
  - pcr-oracle.8: add a section on pcr policy sealing
  - Add self-test subcommand to pcr-oracle
  - Rename __tss_check_error -> tss_check_error
  - Moved two tss related functions to a file of their own
  - Add test-pcr.sh script
  - Use the same SRK template as the one in grub2
  - Implement seal/unseal using a regular PCR policy
  - When displaying the DevicePath, print ACPI PNP ids
  - Handle failure to read EFI variables more gracefully
  - Gracefully handle AUTHORITY events for eg driver BSAs that
    reside in ROM
  - efi-variable rehash: break out the code to detect how the
    firmware hashed the event
* Thu Jun  1 2023 Marcus Meissner <meissner@suse.com>
- build with optflags, remove unneeded clean section, macro bindir
* Mon Jan 16 2023 Olaf Kirch <okir@suse.com>
- Updated to version 0.4.2
* Thu Jan  5 2023 Michal Suchanek <msuchanek@suse.com>
- Fix project URL
* Wed Jan  4 2023 Olaf Kirch <okir@suse.com>
- add --rsa-generate-key option
* Tue Jan  3 2023 Olaf Kirch <okir@suse.com>
- Updated to version 0.4.1:
  - disable debug messages from authenticode PECOFF parser
  - add --tpm-eventlog option
  - add manpage
* Mon Jan  2 2023 Olaf Kirch <okir@suse.com>
- Updated to version 0.4:
  - drop the dependency on tss2 fapi
  - introduce authorized policies
* Tue Nov  8 2022 Olaf Kirch <okir@suse.com>
- Establish pcr-oracle as standalone package, apart from fde-tools
